@@ -1774,8 +1774,9 @@ error:
 static int
 EvdevProbe(InputInfoPtr pInfo)
 {
-    int i, has_rel_axes, has_abs_axes, has_xy, has_keys, num_buttons, has_scroll;
+    int i, has_rel_axes, has_abs_axes, has_keys, num_buttons, has_scroll;
     int kernel24 = 0;
+    int ignore_rel, ignore_abs;
     EvdevPtr pEvdev = pInfo->private;
 
     if (pEvdev->grabDevice && ioctl(pInfo->fd, EVIOCGRAB, (void *)1)) {
@@ -1791,9 +1792,11 @@ EvdevProbe(InputInfoPtr pInfo)
         ioctl(pInfo->fd, EVIOCGRAB, (void *)0);
     }
 
+    ignore_rel = xf86SetBoolOption(pInfo->options, "IgnoreRelativeAxes", FALSE);
+    ignore_abs = xf86SetBoolOption(pInfo->options, "IgnoreAbsoluteAxes", FALSE);
+
     has_rel_axes = FALSE;
     has_abs_axes = FALSE;
-    has_xy = FALSE;
     has_keys = FALSE;
     has_scroll = FALSE;
     num_buttons = 0;
@@ -1804,8 +1807,7 @@ EvdevProbe(InputInfoPtr pInfo)
         int mapping = 0;
         if (TestBit(i, pEvdev->key_bitmask))
         {
-            mapping =
-                pEvdev->btnmap[EvdevUtilButtonEventToButtonNumber(pEvdev, i)];
+            mapping = EvdevUtilButtonEventToButtonNumber(pEvdev, i);
             if (mapping > num_buttons)
                 num_buttons = mapping;
         }
@@ -1827,14 +1829,6 @@ EvdevProbe(InputInfoPtr pInfo)
     }
 
     if (has_rel_axes) {
-        xf86Msg(X_INFO, "%s: found relative axes\n", pInfo->name);
-        pEvdev->flags |= EVDEV_RELATIVE_EVENTS;
-        if (TestBit(REL_X, pEvdev->rel_bitmask) &&
-            TestBit(REL_Y, pEvdev->rel_bitmask)) {
-            xf86Msg(X_INFO, "%s: Found x and y relative axes\n", pInfo->name);
-            has_xy = TRUE;
-        }
-
         if (TestBit(REL_WHEEL, pEvdev->rel_bitmask) ||
             TestBit(REL_HWHEEL, pEvdev->rel_bitmask) ||
             TestBit(REL_DIAL, pEvdev->rel_bitmask)) {
@@ -1846,6 +1840,20 @@ EvdevProbe(InputInfoPtr pInfo)
             num_buttons = (num_buttons < 3) ? 7 : num_buttons + 4;
             pEvdev->num_buttons = num_buttons;
         }
+
+        if (!ignore_rel)
+        {
+            xf86Msg(X_INFO, "%s: found relative axes\n", pInfo->name);
+            pEvdev->flags |= EVDEV_RELATIVE_EVENTS;
+
+            if (TestBit(REL_X, pEvdev->rel_bitmask) &&
+                TestBit(REL_Y, pEvdev->rel_bitmask)) {
+                xf86Msg(X_INFO, "%s: Found x and y relative axes\n", pInfo->name);
+            }
+        } else {
+            xf86Msg(X_INFO, "%s: relative axes present but ignored.\n", pInfo->name);
+            has_rel_axes = FALSE;
+        }
     }
 
     for (i = 0; i < ABS_MAX; i++) {
@@ -1855,7 +1863,11 @@ EvdevProbe(InputInfoPtr pInfo)
         }
     }
 
-    if (has_abs_axes) {
+    if (ignore_abs && has_abs_axes)
+    {
+        xf86Msg(X_INFO, "%s: absolute axes present but ignored.\n", pInfo->name);
+        has_abs_axes = FALSE;
+    } else if (has_abs_axes) {
         xf86Msg(X_INFO, "%s: found absolute axes\n", pInfo->name);
         pEvdev->flags |= EVDEV_ABSOLUTE_EVENTS;
 
@@ -1878,7 +1890,6 @@ EvdevProbe(InputInfoPtr pInfo)
                     pEvdev->flags |= EVDEV_BUTTON_EVENTS;
                 }
             }
-            has_xy = TRUE;
         }
     }
 
